@@ -39,7 +39,7 @@ import java.util.Properties;
  * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
  * @author <a href="evenisse@apache.org">Emmanuel Venisse</a>
  * @author <a href="mailto:vincent.siveton@gmail.com">Vincent Siveton</a>
- * @version $Id: AbstractMavenReportRenderer.java 748481 2009-02-27 10:51:56Z vsiveton $
+ * @version $Id: AbstractMavenReportRenderer.java 942606 2010-05-09 20:17:20Z hboutemy $
  * @since 2.0
  * @TODO Later it may be appropriate to create something like a VelocityMavenReportRenderer
  * that could take a velocity template and pipe that through Doxia rather than coding them
@@ -113,9 +113,6 @@ public abstract class AbstractMavenReportRenderer
     {
         section = section + 1;
 
-        sink.anchor( HtmlTools.encodeId( name ) );
-        sink.anchor_();
-
         switch ( section )
         {
             case 1:
@@ -168,6 +165,9 @@ public abstract class AbstractMavenReportRenderer
                 // TODO: warning - just don't start a section
                 break;
         }
+
+        sink.anchor( HtmlTools.encodeId( name ) );
+        sink.anchor_();
     }
 
     /**
@@ -223,8 +223,24 @@ public abstract class AbstractMavenReportRenderer
      * @see Sink#table()
      */
     protected void startTable()
+    {
+        startTable( new int[] {Sink.JUSTIFY_LEFT}, false );
+    }
+
+    /**
+     * Convenience method to wrap the table start in the current sink.
+     *
+     * @param justification the justification of table cells.
+     * @param grid whether to draw a grid around cells.
+     *
+     * @see Sink#table()
+     * @see Sink#tableRows(int[],boolean)
+     * @since 2.1
+     */
+    protected void startTable( int[] justification, boolean grid )
     {
         sink.table();
+        sink.tableRows( justification, grid );
     }
 
     /**
@@ -234,6 +250,7 @@ public abstract class AbstractMavenReportRenderer
      */
     protected void endTable()
     {
+        sink.tableRows_();
         sink.table_();
     }
 
@@ -603,9 +620,9 @@ public abstract class AbstractMavenReportRenderer
         String[] schemes = {"http", "https"};
         UrlValidator urlValidator = new UrlValidator( schemes );
 
-        if ( ( EmailValidator.getInstance().isValid( href ) ) ||
-             ( ( href.indexOf( "?" ) != -1 ) &&
-               ( EmailValidator.getInstance().isValid( href.substring( 0, href.indexOf( "?" ) ) ) ) ) )
+        if ( ( EmailValidator.getInstance().isValid( href ) )
+            || ( ( href.indexOf( "?" ) != -1 )
+                 && ( EmailValidator.getInstance().isValid( href.substring( 0, href.indexOf( "?" ) ) ) ) ) )
         {
             return "mailto:" + href;
         }
@@ -638,7 +655,7 @@ public abstract class AbstractMavenReportRenderer
             {
                 if ( href.length() > 2 )
                 {
-                    return href.substring(2, href.length() );
+                    return href.substring( 2, href.length() );
                 }
 
                 return ".";
